@@ -52,7 +52,7 @@ class NodeTemplate:  # pylint: disable=too-many-instance-attributes
     node_template_type: str
     model_name: str
     model_version_id: str
-    model_invariant_id: str
+    model_invartiant_id: str
     model_version: str
     model_customization_id: str
     model_instance_name: str
@@ -297,9 +297,9 @@ class Service(SdcResource):  # pylint: disable=too-many-instance-attributes, too
             node_template_type=component.tosca_component_name,
             model_name=component.component_name,
             model_version_id=component.sdc_resource.identifier,
-            model_invariant_id=component.sdc_resource.unique_uuid,
+            model_invartiant_id=component.sdc_resource.unique_uuid,
             model_version=component.sdc_resource.version,
-            model_customization_id=component.customization_uuid,
+            model_customization_id=component.component_name,
             model_instance_name=self.name,
             component=component
         )
@@ -332,41 +332,8 @@ class Service(SdcResource):  # pylint: disable=too-many-instance-attributes, too
                         ))
         return node_template
 
-    def __has_component_type(self, origin_type: str) -> bool:
-        """Check if any of Service's component type is provided origin type.
-
-        In template generation is checked if Service has some types of components,
-            based on that blocks are added to the request template. It's not
-            the best option to get all components to check if at least one with
-            given type exists for conditional statement.
-
-        Args:
-            origin_type (str): Type to check if any component exists.
-
-        Returns:
-            bool: True if service has at least one component with given origin type,
-                False otherwise
-
-        """
-        return any((component.origin_type == origin_type for component in self.components))
-
     @property
-    def has_vnfs(self) -> bool:
-        """Check if service has at least one VF component."""
-        return self.__has_component_type("VF")
-
-    @property
-    def has_pnfs(self) -> bool:
-        """Check if service has at least one PNF component."""
-        return self.__has_component_type("PNF")
-
-    @property
-    def has_vls(self) -> bool:
-        """Check if service has at least one VL component."""
-        return self.__has_component_type("VL")
-
-    @property
-    def vnfs(self) -> Iterator[Vnf]:
+    def vnfs(self) -> List[Vnf]:
         """Service Vnfs.
 
         Load VNFs from components generator.
@@ -381,6 +348,39 @@ class Service(SdcResource):  # pylint: disable=too-many-instance-attributes, too
         for component in self.components:
             if component.origin_type == "VF":
                 yield self.create_node_template(Vnf, component)
+        #         vnf: Vnf = Vnf(
+        #             name=component.name,
+        #             node_template_type=component.tosca_component_name,
+        #             model_name=component.component_name,
+        #             model_version_id=component.sdc_resource.identifier,
+        #             model_invartiant_id=component.sdc_resource.unique_uuid,
+        #             model_version=component.sdc_resource.version,
+        #             model_customization_id=component.component_name,
+        #             model_instance_name=self.name,
+        #             component=component
+        #         )
+        #         if component.group_instances:
+        #             for vf_module in component.group_instances:
+        #                 if "dummy" not in vf_module["name"]:
+        #                     vnf.vf_modules.append(VfModule(
+        #                         name=vf_module["name"],
+        #                         group_type=vf_module["type"],
+        #                         model_name=vf_module["groupName"],
+        #                         model_version_id=vf_module["groupUUID"],
+        #                         model_invariant_uuid=vf_module["invariantUUID"],
+        #                         model_version=vf_module["version"],
+        #                         model_customization_id=vf_module["customizationUUID"],
+        #                         properties=(
+        #                             Property(
+        #                                 name=property_def["name"],
+        #                                 property_type=property_def["type"],
+        #                                 description=property_def["description"],
+        #                                 value=property_def["value"]
+        #                             ) for property_def in vf_module["properties"] \
+        #                                 if property_def["value"]
+        #                         )
+        #                     ))
+        #         yield vnf
 
     @property
     def pnfs(self) -> Iterator[Pnf]:
@@ -395,6 +395,19 @@ class Service(SdcResource):  # pylint: disable=too-many-instance-attributes, too
         for component in self.components:
             if component.origin_type == "PNF":
                 yield self.create_node_template(Pnf, component)
+        # for component in self.components:
+        #     if component.origin_type == "PNF":
+        #         yield Pnf(
+        #             name=component.name,
+        #             node_template_type=component.tosca_component_name,
+        #             model_name=component.component_name,
+        #             model_version_id=component.sdc_resource.identifier,
+        #             model_invartiant_id=component.sdc_resource.unique_uuid,
+        #             model_version=component.sdc_resource.version,
+        #             model_customization_id=component.component_name,
+        #             model_instance_name=self.name,
+        #             component=component
+        #         )
 
     @property
     def networks(self) -> Iterator[Network]:
@@ -409,6 +422,19 @@ class Service(SdcResource):  # pylint: disable=too-many-instance-attributes, too
         for component in self.components:
             if component.origin_type == "VL":
                 yield self.create_node_template(Network, component)
+        # for component in self.components:
+        #     if component.origin_type == "VL":
+        #         yield Network(
+        #             name=component.name,
+        #             node_template_type=component.tosca_component_name,
+        #             model_name=component.component_name,
+        #             model_version_id=component.sdc_resource.identifier,
+        #             model_invartiant_id=component.sdc_resource.unique_uuid,
+        #             model_version=component.sdc_resource.version,
+        #             model_customization_id=component.component_name,
+        #             model_instance_name=self.name,
+        #             component=component
+        #         )
 
     @property
     def deployment_artifacts_url(self) -> str:
