@@ -6,7 +6,6 @@ from abc import ABC
 from dataclasses import dataclass, field
 from typing import Any, Dict, Iterable, List, Optional
 from uuid import uuid4
-from warnings import warn
 
 from dacite import from_dict
 
@@ -19,27 +18,10 @@ from onapsdk.sdnc import NetworkPreload, VfModulePreload
 from onapsdk.sdc.service import Network, Service as SdcService, Vnf, VfModule
 from onapsdk.utils.jinja import jinja_env
 from onapsdk.utils.headers_creator import headers_so_creator
-from onapsdk.vid import LineOfBusiness, Platform
-from onapsdk.configuration import settings
 
 from .so_element import OrchestrationRequest
 
 
-@dataclass
-class Operation:
-    """Operation class with data about method and suffix for VnfOperation."""
-
-    request_method: str
-    request_suffix: str
-
-
-class VnfOperation(Operation):  # pylint: disable=too-few-public-methods
-    """Class to store possible operations' data for vnfs (request method and suffix)."""
-
-    UPDATE = Operation("PUT", "")
-    HEALTHCHECK = Operation("POST", "/healthcheck")
-
-
 @dataclass
 class SoServiceVfModule:
     """Class to store a VfModule instance parameters."""
@@ -51,37 +33,14 @@ class SoServiceVfModule:
 
 
 @dataclass
-class SoServiceXnf:
-    """Class to store a Xnf instance parameters."""
+class SoServiceVnf:
+    """Class to store a Vnf instance parameters."""
 
     model_name: str
     instance_name: str
     parameters: Dict[str, Any] = field(default_factory=dict)
-    processing_priority: Optional[int] = None
-
-    @classmethod
-    def load(cls, data: Dict[str, Any]) -> "SoServiceVnf":
-        """Create a vnf instance description object from the dict.
-
-        Useful if you keep your instance data in file.
-
-        Returns:
-            SoServiceVnf: SoServiceVnf object created from the dictionary
-
-        """
-        return from_dict(data_class=cls, data=data)
-
-
-@dataclass
-class SoServiceVnf(SoServiceXnf):
-    """Class to store a Vnf instance parameters."""
-
     vf_modules: List[SoServiceVfModule] = field(default_factory=list)
-
-
-@dataclass
-class SoServicePnf(SoServiceXnf):
-    """Class to store a Pnf instance parameters."""
+    processing_priority: Optional[int] = None
 
 
 @dataclass
@@ -94,7 +53,6 @@ class SoService:
 
     subscription_service_type: str
     vnfs: List[SoServiceVnf] = field(default_factory=list)
-    pnfs: List[SoServicePnf] = field(default_factory=list)
     instance_name: Optional[str] = None
 
     @classmethod
@@ -110,6 +68,7 @@ class SoService:
         return from_dict(data_class=cls, data=data)
 
 
+
 @dataclass
 class VnfParameters:
     """Class to store vnf parameters used for macro instantiation.
@@ -222,8 +181,8 @@ class VfModuleInstantiation(Instantiation):  # pytest: disable=too-many-ancestor
     def instantiate_ala_carte(cls,  # pylint: disable=too-many-arguments
                               vf_module: "VfModule",
                               vnf_instance: "VnfInstance",
-                              cloud_region: "CloudRegion" = None,
-                              tenant: "Tenant" = None,
+                              cloud_region: "CloudRegion",
+                              tenant: "Tenant",
                               vf_module_instance_name: str = None,
                               vnf_parameters: Iterable["InstantiationParameter"] = None,
                               use_preload: bool = True) -> "VfModuleInstantiation":
@@ -236,12 +195,8 @@ class VfModuleInstantiation(Instantiation):  # pytest: disable=too-many-ancestor
             vnf_instance (VnfInstance): VnfInstance object
             cloud_region (CloudRegion, optional): Cloud region to use in instantiation request.
                 Defaults to None.
-                THAT PROPERTY WILL BE REQUIRED IN ONE OF THE FUTURE RELEASE. REFACTOR YOUR CODE
-                TO USE IT!.
             tenant (Tenant, optional): Tenant to use in instnatiation request.
                 Defaults to None.
-                THAT PROPERTY WILL BE REQUIRED IN ONE OF THE FUTURE RELEASE. REFACTOR YOUR CODE
-                TO USE IT!.
             vf_module_instance_name_factory (str, optional): Factory to create VF module names.
                 It's going to be a prefix of name. Index of vf module in Tosca file will be
                 added to it.
@@ -282,10 +237,8 @@ class VfModuleInstantiation(Instantiation):  # pytest: disable=too-many-ancestor
                 vf_module_instance_name=vf_module_instance_name,
                 vf_module=vf_module,
                 service=sdc_service,
-                cloud_region=cloud_region or \
-                    vnf_instance.service_instance.service_subscription.cloud_region,
-                tenant=tenant or \
-                    vnf_instance.service_instance.service_subscription.tenant,
+                cloud_region=cloud_region,
+                tenant=tenant,
                 vnf_instance=vnf_instance,
                 vf_module_parameters=vnf_parameters or []
             ),
@@ -298,7 +251,6 @@ class VfModuleInstantiation(Instantiation):  # pytest: disable=too-many-ancestor
             vf_module=vf_module
         )
 
-
 class NodeTemplateInstantiation(Instantiation, ABC):  # pytest: disable=too-many-ancestors
     """Base class for service's node_template object instantiation."""
 
@@ -306,16 +258,16 @@ class NodeTemplateInstantiation(Instantiation, ABC):  # pytest: disable=too-many
                  name: str,
                  request_id: str,
                  instance_id: str,
-                 line_of_business: LineOfBusiness,
-                 platform: Platform) -> None:
+                 line_of_business: str,
+                 platform: str) -> None:
         """Node template object initialization.
 
         Args:
             name (str): Node template name
             request_id (str): Node template instantiation request ID
             instance_id (str): Node template instance ID
-            line_of_business (LineOfBusiness): LineOfBusiness class object used for instantation
-            platform (Platform): Platform class object used for instantiation
+            line_of_business (str): LineOfBusiness name
+            platform (str): Platform name
         """
         super().__init__(name, request_id, instance_id)
         self.line_of_business = line_of_business
@@ -329,8 +281,8 @@ class VnfInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-many-a
                  name: str,
                  request_id: str,
                  instance_id: str,
-                 line_of_business: LineOfBusiness,
-                 platform: Platform,
+                 line_of_business: str,
+                 platform: str,
                  vnf: Vnf) -> None:
         """Class VnfInstantion object initialization.
 
@@ -339,8 +291,8 @@ class VnfInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-many-a
             request_id (str): request ID
             instance_id (str): instance ID
             service_instantiation ([type]): ServiceInstantiation class object
-            line_of_business (LineOfBusiness): LineOfBusiness class object
-            platform (Platform): Platform class object
+            line_of_business (str): LineOfBusiness name
+            platform (str): Platform name
             vnf (Vnf): Vnf class object
         """
         super().__init__(name, request_id, instance_id, line_of_business, platform)
@@ -384,10 +336,10 @@ class VnfInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-many-a
                 request_id=request_response.get("request", {}).get("requestId"),
                 instance_id=request_response.get("request", {})\
                     .get("instanceReferences", {}).get("vnfInstanceId"),
-                line_of_business=LineOfBusiness.create(request_response.get("request", {})\
-                    .get("requestDetails", {}).get("lineOfBusiness", {}).get("lineOfBusinessName")),
-                platform=Platform.create(request_response.get("request", {})\
-                    .get("requestDetails", {}).get("platform", {}).get("platformName")),
+                line_of_business=request_response.get("request", {})\
+                    .get("requestDetails", {}).get("lineOfBusiness", {}).get("lineOfBusinessName"),
+                platform=request_response.get("request", {})\
+                    .get("requestDetails", {}).get("platform", {}).get("platformName"),
                 vnf=vnf
             )
         raise InvalidResponse("Invalid vnf instantions in response dictionary's requestList")
@@ -423,8 +375,8 @@ class VnfInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-many-a
     def instantiate_ala_carte(cls,  # pylint: disable=too-many-arguments
                               aai_service_instance: "ServiceInstance",
                               vnf_object: "Vnf",
-                              line_of_business_object: "LineOfBusiness",
-                              platform_object: "Platform",
+                              line_of_business: str,
+                              platform: str,
                               cloud_region: "CloudRegion",
                               tenant: "Tenant",
                               sdc_service: "SdcService",
@@ -437,14 +389,8 @@ class VnfInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-many-a
             vnf_object (Vnf): Vnf to instantiate
             line_of_business_object (LineOfBusiness): LineOfBusiness to use in instantiation request
             platform_object (Platform): Platform to use in instantiation request
-            cloud_region (CloudRegion, optional): Cloud region to use in instantiation request.
-                Defaults to None.
-                THAT PROPERTY WILL BE REQUIRED IN ONE OF THE FUTURE RELEASE. REFACTOR YOUR CODE
-                TO USE IT!.
-            tenant (Tenant, optional): Tenant to use in instnatiation request.
-                Defaults to None.
-                THAT PROPERTY WILL BE REQUIRED IN ONE OF THE FUTURE RELEASE. REFACTOR YOUR CODE
-                TO USE IT!.
+            cloud_region (CloudRegion): Cloud region to use in instantiation request.
+            tenant (Tenant): Tenant to use in instnatiation request.
             vnf_instance_name (str, optional): Vnf instance name. Defaults to None.
             vnf_parameters (Iterable[InstantiationParameter], optional): Instantiation parameters
                 that are sent in the request. Defaults to None
@@ -468,101 +414,15 @@ class VnfInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-many-a
                 vnf=vnf_object,
                 service=sdc_service,
                 cloud_region=cloud_region or \
-                    aai_service_instance.service_subscription.cloud_region,
-                tenant=tenant or aai_service_instance.service_subscription.tenant,
-                line_of_business=line_of_business_object,
-                platform=platform_object,
+                    next(aai_service_instance.service_subscription.cloud_regions),
+                tenant=tenant or next(aai_service_instance.service_subscription.tenants),
+                line_of_business=line_of_business,
+                platform=platform,
                 service_instance=aai_service_instance,
                 vnf_parameters=vnf_parameters or []
             ),
             headers=headers_so_creator(OnapService.headers)
         )
-        return VnfInstantiation(
-            name=vnf_instance_name,
-            request_id=response["requestReferences"]["requestId"],
-            instance_id=response["requestReferences"]["instanceId"],
-            line_of_business=line_of_business_object,
-            platform=platform_object,
-            vnf=vnf_object
-        )
-
-    @classmethod
-    def instantiate_macro(cls,  # pylint: disable=too-many-arguments, too-many-locals
-                          aai_service_instance: "ServiceInstance",
-                          vnf_object: "Vnf",
-                          line_of_business: str,
-                          platform: str,
-                          cloud_region: "CloudRegion",
-                          tenant: "Tenant",
-                          sdc_service: "SdcService",
-                          vnf_instance_name: str = None,
-                          vnf_parameters: Iterable["InstantiationParameter"] = None,
-                          so_vnf: "SoServiceVnf" = None
-                          ) -> "VnfInstantiation":
-        """Instantiate Vnf using macro method.
-
-        Args:
-            aai_service_instance (ServiceInstance): Service instance associated with request
-            vnf_object (Vnf): Vnf to instantiate
-            line_of_business (LineOfBusiness): LineOfBusiness to use in instantiation request
-            platform (Platform): Platform to use in instantiation request
-            cloud_region (CloudRegion): Cloud region to use in instantiation request.
-            tenant (Tenant): Tenant to use in instantiation request.
-            vnf_instance_name (str, optional): Vnf instance name. Defaults to None.
-            vnf_parameters (Iterable[InstantiationParameter], optional): Instantiation parameters
-                that are sent in the request. Defaults to None
-            so_vnf (SoServiceVnf): object with vnf instance parameters
-
-        Returns:
-            VnfInstantiation: VnfInstantiation object
-
-        """
-        owning_entity_id = None
-        project = settings.PROJECT
-
-        for relationship in aai_service_instance.relationships:
-            if relationship.related_to == "owning-entity":
-                owning_entity_id = relationship.relationship_data.pop().get("relationship-value")
-            if relationship.related_to == "project":
-                project = relationship.relationship_data.pop().get("relationship-value")
-
-        owning_entity = OwningEntity.get_by_owning_entity_id(
-            owning_entity_id=owning_entity_id)
-
-        if so_vnf:
-            template_file = "instantiate_vnf_macro_so_vnf.json.j2"
-            if so_vnf.instance_name:
-                vnf_instance_name = so_vnf.instance_name
-        else:
-            template_file = "instantiate_vnf_macro.json.j2"
-            if vnf_instance_name is None:
-                vnf_instance_name = \
-                    f"Python_ONAP_SDK_vnf_instance_{str(uuid4())}"
-
-        response: dict = cls.send_message_json(
-            "POST",
-            (f"Instantiate {sdc_service.name} "
-             f"service vnf {vnf_object.name}"),
-            (f"{cls.base_url}/onap/so/infra/serviceInstantiation/{cls.api_version}/"
-             f"serviceInstances/{aai_service_instance.instance_id}/vnfs"),
-            data=jinja_env().get_template(template_file).render(
-                instance_name=vnf_instance_name,
-                vnf=vnf_object,
-                service=sdc_service,
-                cloud_region=cloud_region or \
-                             next(aai_service_instance.service_subscription.cloud_regions),
-                tenant=tenant or next(aai_service_instance.service_subscription.tenants),
-                project=project,
-                owning_entity=owning_entity,
-                line_of_business=line_of_business,
-                platform=platform,
-                service_instance=aai_service_instance,
-                vnf_parameters=vnf_parameters or [],
-                so_vnf=so_vnf
-            ),
-            headers=headers_so_creator(OnapService.headers)
-        )
-
         return VnfInstantiation(
             name=vnf_instance_name,
             request_id=response["requestReferences"]["requestId"],
@@ -572,82 +432,6 @@ class VnfInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-many-a
             vnf=vnf_object
         )
 
-    @classmethod
-    def so_action(cls,  # pylint: disable=too-many-arguments, too-many-locals
-                  vnf_instance: "VnfInstance",
-                  operation_type: VnfOperation,
-                  aai_service_instance: "ServiceInstance",
-                  line_of_business: str,
-                  platform: str,
-                  sdc_service: "SdcService",
-                  so_service: "SoService" = None
-                  ) -> "VnfInstantiation":
-        """Execute SO action (update or healthcheck) for selected vnf with SO macro request.
-
-        Args:
-            vnf_instance (VnfInstance): vnf instance object
-            operation_type (VnfOperation): name of the operation to trigger
-            aai_service_instance (AaiService): Service Instance object from aai
-            line_of_business (LineOfBusiness): LineOfBusiness name to use
-                in instantiation request
-            platform (Platform): Platform name to use in instantiation request
-            sdc_service (SdcService): Service model information
-            so_service (SoService, optional): SO values to use in SO request
-
-        Raises:
-            StatusError: if the provided operation is not supported
-
-        Returns:
-            VnfInstantiation: VnfInstantiation object
-
-        """
-        if operation_type not in (VnfOperation.HEALTHCHECK, VnfOperation.UPDATE):
-            raise StatusError("Operation not supported!")
-
-        owning_entity_id = None
-        project = settings.PROJECT
-
-        for relationship in aai_service_instance.relationships:
-            if relationship.related_to == "owning-entity":
-                owning_entity_id = relationship.relationship_data.pop().get("relationship-value")
-            if relationship.related_to == "project":
-                project = relationship.relationship_data.pop().get("relationship-value")
-
-        owning_entity = OwningEntity.get_by_owning_entity_id(
-            owning_entity_id=owning_entity_id)
-
-        response: dict = cls.send_message_json(
-            operation_type.request_method,
-            (f"So Action {sdc_service.name} "
-             f" vnf instance {vnf_instance.vnf_id}"),
-            (f"{cls.base_url}/onap/so/infra/serviceInstantiation/{cls.api_version}/"
-             f"serviceInstances/{aai_service_instance.instance_id}/vnfs/{vnf_instance.vnf_id}"
-             f"{operation_type.request_suffix}"),
-            data=jinja_env().get_template("instantiate_multi_vnf_service_macro.json.j2").render(
-                sdc_service=sdc_service,
-                cloud_region=next(aai_service_instance.service_subscription.cloud_regions),
-                tenant=next(aai_service_instance.service_subscription.tenants),
-                customer=aai_service_instance.service_subscription.customer,
-                project=project,
-                owning_entity=owning_entity,
-                line_of_business=line_of_business,
-                platform=platform,
-                service_instance_name=aai_service_instance.instance_name,
-                so_service=so_service
-            ),
-            headers=headers_so_creator(OnapService.headers)
-        )
-
-        return VnfInstantiation(
-            name=vnf_instance.vnf_name,
-            request_id=response["requestReferences"]["requestId"],
-            instance_id=response["requestReferences"]["instanceId"],
-            line_of_business=line_of_business,
-            platform=platform,
-            vnf=vnf_instance
-        )
-
-
 class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
     """Service instantiation class."""
 
@@ -659,8 +443,8 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
                  cloud_region: "CloudRegion",
                  tenant: "Tenant",
                  customer: "Customer",
-                 owning_entity: "OwningEntity",
-                 project: "Project") -> None:
+                 owning_entity: OwningEntity,
+                 project: str) -> None:
         """Class ServiceInstantiation object initialization.
 
         Args:
@@ -672,7 +456,7 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
             tenant (Tenant): Tenant class object
             customer (Customer): Customer class object
             owning_entity (OwningEntity): OwningEntity class object
-            project (Project): Project class object
+            project (str): Project name
 
         """
         super().__init__(name, request_id, instance_id)
@@ -683,47 +467,14 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
         self.owning_entity = owning_entity
         self.project = project
 
-    @classmethod
-    def instantiate_so_ala_carte(cls,  # pylint: disable=too-many-arguments
-                                 sdc_service: "SdcService",
-                                 cloud_region: "CloudRegion",
-                                 tenant: "Tenant",
-                                 customer: "Customer",
-                                 owning_entity: "OwningEntity",
-                                 project: "Project",
-                                 service_subscription: "ServiceSubscription",
-                                 service_instance_name: str = None) -> "ServiceInstantiation":
-        """Instantiate service using SO a'la carte request.
-
-        THIS METHOD IS DEPRECATED! USE `instantiate_ala_carte`.
-
-        Args:
-            sdc_service (SdcService): Service to instantiate
-            cloud_region (CloudRegion): Cloud region to use in instantiation request
-            tenant (Tenant): Tenant to use in instantiation request
-            customer (Customer): Customer to use in instantiation request
-            owning_entity (OwningEntity): Owning entity to use in instantiation request
-            project (Project): Project to use in instantiation request
-            service_instance_name (str, optional): Service instance name. Defaults to None.
-            service_subscription (ServiceSubscription): Customer's service subsription.
-
-        Returns:
-            ServiceInstantiation: instantiation request object
-
-        """
-        warn("This method is deprecated, use `instantiate_ala_carte`.", DeprecationWarning)
-        return cls.instantiate_ala_carte(sdc_service, cloud_region, tenant, customer,
-                                         owning_entity, project, service_subscription,
-                                         service_instance_name)
-
     @classmethod
     def instantiate_ala_carte(cls,  # pylint: disable=too-many-arguments
                               sdc_service: "SdcService",
                               cloud_region: "CloudRegion",
                               tenant: "Tenant",
                               customer: "Customer",
-                              owning_entity: "OwningEntity",
-                              project: "Project",
+                              owning_entity: OwningEntity,
+                              project: str,
                               service_subscription: "ServiceSubscription",
                               service_instance_name: str = None,
                               enable_multicloud: bool = False) -> "ServiceInstantiation":
@@ -735,7 +486,7 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
             tenant (Tenant): Tenant to use in instantiation request
             customer (Customer): Customer to use in instantiation request
             owning_entity (OwningEntity): Owning entity to use in instantiation request
-            project (Project): Project to use in instantiation request
+            project (str): Project name to use in instantiation request
             service_subscription (ServiceSubscription): Customer's service subsription.
             service_instance_name (str, optional): Service instance name. Defaults to None.
             enable_multicloud (bool, optional): Determines if Multicloud should be enabled
@@ -789,10 +540,10 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
     def instantiate_macro(cls,
                           sdc_service: "SdcService",
                           customer: "Customer",
-                          owning_entity: "OwningEntity",
-                          project: "Project",
-                          line_of_business: "LineOfBusiness",
-                          platform: "Platform",
+                          owning_entity: OwningEntity,
+                          project: str,
+                          line_of_business: str,
+                          platform: str,
                           aai_service: "AaiService" = None,
                           cloud_region: "CloudRegion" = None,
                           tenant: "Tenant" = None,
@@ -808,10 +559,10 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
             sdc_service (SdcService): Service to instantiate
             customer (Customer): Customer to use in instantiation request
             owning_entity (OwningEntity): Owning entity to use in instantiation request
-            project (Project): Project to use in instantiation request
-            line_of_business_object (LineOfBusiness): LineOfBusiness to use
+            project (Project): Project name to use in instantiation request
+            line_of_business_object (LineOfBusiness): LineOfBusiness name to use
                 in instantiation request
-            platform_object (Platform): Platform to use in instantiation request
+            platform_object (Platform): Platform name to use in instantiation request
             aai_service (AaiService): Service object from aai sdc
             cloud_region (CloudRegion): Cloud region to use in instantiation request
             tenant (Tenant): Tenant to use in instantiation request
@@ -884,7 +635,7 @@ class ServiceInstantiation(Instantiation):  # pylint: disable=too-many-ancestors
 
     @property
     def aai_service_instance(self) -> "ServiceInstance":
-        """Service instance associated with service instantiation request.
+        """Service instane associated with service instantiation request.
 
         Raises:
             StatusError: if a service is not instantiated -
@@ -916,8 +667,8 @@ class NetworkInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-ma
                  name: str,
                  request_id: str,
                  instance_id: str,
-                 line_of_business: LineOfBusiness,
-                 platform: Platform,
+                 line_of_business: str,
+                 platform: str,
                  network: Network) -> None:
         """Class NetworkInstantiation object initialization.
 
@@ -926,8 +677,8 @@ class NetworkInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-ma
             request_id (str): request ID
             instance_id (str): instance ID
             service_instantiation ([type]): ServiceInstantiation class object
-            line_of_business (LineOfBusiness): LineOfBusiness class object
-            platform (Platform): Platform class object
+            line_of_business (str): LineOfBusiness name
+            platform (str): Platform name
             vnf (Network): Network class object
         """
         super().__init__(name, request_id, instance_id, line_of_business, platform)
@@ -937,26 +688,20 @@ class NetworkInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-ma
     def instantiate_ala_carte(cls,  # pylint: disable=too-many-arguments
                               aai_service_instance: "ServiceInstance",
                               network_object: "Network",
-                              line_of_business_object: "LineOfBusiness",
-                              platform_object: "Platform",
-                              cloud_region: "CloudRegion" = None,
-                              tenant: "Tenant" = None,
+                              line_of_business: str,
+                              platform: str,
+                              cloud_region: "CloudRegion",
+                              tenant: "Tenant",
                               network_instance_name: str = None,
                               subnets: Iterable[Subnet] = None) -> "NetworkInstantiation":
         """Instantiate Network using a'la carte method.
 
         Args:
             network_object (Network): Network to instantiate
-            line_of_business_object (LineOfBusiness): LineOfBusiness to use in instantiation request
-            platform_object (Platform): Platform to use in instantiation request
-            cloud_region (CloudRegion, optional): Cloud region to use in instantiation request.
-                Defaults to None.
-                THAT PROPERTY WILL BE REQUIRED IN ONE OF THE FUTURE RELEASE. REFACTOR YOUR CODE
-                TO USE IT!.
-            tenant (Tenant, optional): Tenant to use in instnatiation request.
-                Defaults to None.
-                THAT PROPERTY WILL BE REQUIRED IN ONE OF THE FUTURE RELEASE. REFACTOR YOUR CODE
-                TO USE IT!.
+            line_of_business (str): LineOfBusiness name to use in instantiation request
+            platform (str): Platform name to use in instantiation request
+            cloud_region (CloudRegion): Cloud region to use in instantiation request.
+            tenant (Tenant): Tenant to use in instnatiation request.
             network_instance_name (str, optional): Network instance name. Defaults to None.
 
         Returns:
@@ -981,10 +726,10 @@ class NetworkInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-ma
                 network=network_object,
                 service=aai_service_instance.sdc_service,
                 cloud_region=cloud_region or \
-                    aai_service_instance.service_subscription.cloud_region,
-                tenant=tenant or aai_service_instance.service_subscription.tenant,
-                line_of_business=line_of_business_object,
-                platform=platform_object,
+                    next(aai_service_instance.service_subscription.cloud_regions),
+                tenant=tenant or next(aai_service_instance.service_subscription.tenants),
+                line_of_business=line_of_business,
+                platform=platform,
                 service_instance=aai_service_instance,
                 subnets=subnets
             ),
@@ -994,7 +739,7 @@ class NetworkInstantiation(NodeTemplateInstantiation):  # pylint: disable=too-ma
             name=network_instance_name,
             request_id=response["requestReferences"]["requestId"],
             instance_id=response["requestReferences"]["instanceId"],
-            line_of_business=line_of_business_object,
-            platform=platform_object,
+            line_of_business=line_of_business,
+            platform=platform,
             network=network_object
         )
